@@ -197,6 +197,16 @@ class BaseLog:
         message = json.dumps(data, ensure_ascii=False)
         logging.getLogger(self.journal_log_name).info(message)
 
+    def customize_log(self, data):
+        try:
+            if isinstance(data, dict):
+                message = json.dumps(data, ensure_ascii=False)
+                logging.getLogger(self.journal_log_name).info(message)
+            else:
+                raise ValueError('传入参数必须为字典')
+        except Exception as e:
+            self.error(e)
+
 
 
 
